@@ -60,7 +60,7 @@ QString buildTitle(const QString &description)
         tagName = rx.cap(2);
         if (tagName == QLatin1String("SCRIPT") || tagName == QLatin1String("script")) {
             toReplace = rx.cap(0);    // strip tag AND tag contents
-        } else if (tagName.startsWith(QStringLiteral("br")) || tagName.startsWith(QStringLiteral("BR"))) {
+        } else if (tagName.startsWith(QLatin1String("br")) || tagName.startsWith(QLatin1String("BR"))) {
             toReplace = rx.cap(1);
             replaceWith = QLatin1Char(' ');
         } else {
@@ -156,8 +156,8 @@ private:
 }
 
 Article::Private::Private()
-    : feed(0)
-    , archive(0)
+    : feed(nullptr)
+    , archive(nullptr)
     , status(0)
     , hash(0)
     , pubDate(QDateTime::fromTime_t(1))
@@ -206,7 +206,7 @@ Article::Private::Private(const ItemPtr &article, Feed *feed_, Backend::FeedStor
         //archive->setComments(guid, article.comments());
         //archive->setCommentsLink(guid, article.commentsLink().url());
         archive->setGuidIsPermaLink(guid, false);
-        archive->setGuidIsHash(guid, guid.startsWith(QStringLiteral("hash:")));
+        archive->setGuidIsHash(guid, guid.startsWith(QLatin1String("hash:")));
         const time_t datePublished = article->datePublished();
         if (datePublished > 0) {
             pubDate.setTime_t(datePublished);
@@ -265,13 +265,13 @@ Article::Article(const ItemPtr &article, Feed *feed) : d(new Private(article, fe
 {
 }
 
-Article::Article(const ItemPtr &article, Backend::FeedStorage *archive) : d(new Private(article, 0, archive))
+Article::Article(const ItemPtr &article, Backend::FeedStorage *archive) : d(new Private(article, nullptr, archive))
 {
 }
 
 bool Article::isNull() const
 {
-    return d->archive == 0; // TODO: use proper null state
+    return d->archive == nullptr; // TODO: use proper null state
 }
 
 void Article::offsetPubDate(int secs)
@@ -310,7 +310,7 @@ Article::~Article()
 {
     if (d->deref()) {
         delete d;
-        d = 0;
+        d = nullptr;
     }
 }
 
