@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+   Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,7 +27,7 @@ class ArticleViewerWebEnginePage : public WebEngineViewer::WebEnginePage
     Q_OBJECT
 public:
     explicit ArticleViewerWebEnginePage(QWebEngineProfile *profile, QObject *parent = nullptr);
-    ~ArticleViewerWebEnginePage();
+    ~ArticleViewerWebEnginePage() override;
 
 Q_SIGNALS:
     void urlClicked(const QUrl &url);
