@@ -66,7 +66,7 @@ void FrameManager::slotAddFrame(Frame *frame)
     connect(frame, &Frame::signalTitleChanged, this, &FrameManager::slotSetTitle);
     connect(frame, &Frame::signalStatusText, this, &FrameManager::slotSetStatusText);
 
-    connect(frame, SIGNAL(signalOpenUrlRequest(Akregator::OpenUrlRequest&)), this, SLOT(slotOpenUrlRequest(Akregator::OpenUrlRequest&)));
+    connect(frame, &Frame::signalOpenUrlRequest, this, [this](OpenUrlRequest &request) { slotOpenUrlRequest(request);});
 
     //setPartGuiActive(frame->part(), false);
 
@@ -239,7 +239,8 @@ void FrameManager::openInExternalBrowser(const OpenUrlRequest &request)
     if (request.args().mimeType().isEmpty()) {
         QDesktopServices::openUrl(url);
     } else {
-        KRun::runUrl(url, request.args().mimeType(), 0 /*window*/, false, false);
+        KRun::RunFlags flag = 0;
+        KRun::runUrl(url, request.args().mimeType(), nullptr /*window*/, flag);
     }
 }
 
