@@ -40,11 +40,11 @@ class Application : public KontactInterface::PimUniqueApplication
 public:
     Application(int &argc, char **argv[])
         : KontactInterface::PimUniqueApplication(argc, argv)
-        , mMainWindow(0)
+        , mMainWindow(nullptr)
     {
     }
 
-    ~Application()
+    ~Application() override
     {
     }
 
